import 'dart:async';

import 'amap_location_option.dart';
import 'amap_location_plugin_platform_interface.dart';

///高德定位Flutter插件入口类
class AMapFlutterLocation {
  /// 适配iOS 14定位新特性，只在iOS平台有效
  Future<AMapAccuracyAuthorization> getSystemAccuracyAuthorization() async {
    final result = await AmapLocationPluginPlatform.instance
        .getSystemAccuracyAuthorization();
    return result;
  }

  /// 初始化
  AMapFlutterLocation() {
    AmapLocationPluginPlatform.instance.initKey();
  }

  /// 开始定位
  void startLocation() {
    AmapLocationPluginPlatform.instance.startLocation();
  }

  /// 停止定位
  void stopLocation() {
    AmapLocationPluginPlatform.instance.stopLocation();
    return;
  }

  /// 计算2点之间的距离
  Future<double> calculateDistance(
      double lat1, double lon1, double lat2, double lon2) async {
    var result = await AmapLocationPluginPlatform.instance
        .calculateDistance(lat1, lon1, lat2, lon2);
    return result;
  }

  /// 设置Android和iOS的apikey，建议在weigdet初始化时设置<br>
  /// apiKey的申请请参考高德开放平台官网<br>
  /// Android端: https://lbs.amap.com/api/android-location-sdk/guide/create-project/get-key<br>
  /// iOS端: https://lbs.amap.com/api/ios-location-sdk/guide/create-project/get-key<br>
  /// [androidKey] Android平台的key<br>
  /// [iosKey] ios平台的key<br>
  static void setApiKey(String androidKey, String iosKey) {
    AmapLocationPluginPlatform.instance.setApiKey(androidKey, iosKey);
  }

  /// 设置定位参数
  void setLocationOption(AMapLocationOption locationOption) {
    // Map option = locationOption.getOptionsMap();
    // option['pluginKey'] = _pluginKey;
    AmapLocationPluginPlatform.instance.setLocationOption(locationOption);
  }

  /// 销毁定位
  void destroy() {
    AmapLocationPluginPlatform.instance.destroy();
  }

  /// 定位结果回调
  Stream<Map<String, Object>> onLocationChanged() {
    final result = AmapLocationPluginPlatform.instance.onLocationChanged();
    return result;
  }

  /// 设置是否已经包含高德隐私政策并弹窗展示显示用户查看，如果未包含或者没有弹窗展示，高德定位SDK将不会工作<br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy<br>
  /// <b>必须保证在调用定位功能之前调用， 建议首次启动App时弹出《隐私政策》并取得用户同意</b><br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy
  /// [hasContains] 隐私声明中是否包含高德隐私政策说明<br>
  /// [hasShow] 隐私权政策是否弹窗展示告知用户<br>
  static void updatePrivacyShow(bool hasContains, bool hasShow) {
    AmapLocationPluginPlatform.instance.updatePrivacyShow(hasContains, hasShow);
  }

  /// 设置是否已经取得用户同意，如果未取得用户同意，高德定位SDK将不会工作<br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy<br>
  /// <b>必须保证在调用定位功能之前调用, 建议首次启动App时弹出《隐私政策》并取得用户同意</b><br>
  /// [hasAgree] 隐私权政策是否已经取得用户同意<br>
  static void updatePrivacyAgree(bool hasAgree) {
    AmapLocationPluginPlatform.instance.updatePrivacyAgree(hasAgree);
  }
}
